@@ -5,7 +5,7 @@ use hmacsha::ShaTypes;
 pub fn criterion_benchmark(c: &mut Criterion) {
     let secret_key = "A very strong secret";
     let message = "My secret message";
-    c.bench_function("HOTP Generation", |b| {
+    c.bench_function("SHA-1 Computation", |b| {
         b.iter(|| {
             HmacSha::from(black_box(secret_key), black_box(message), &ShaTypes::Sha1)
                 .compute_digest()
